# -*- coding: utf-8 -*-

"""
direct Python Toolbox
All-in-one toolbox to encapsulate Python runtime variants
----------------------------------------------------------------------------
(C) direct Netware Group - All rights reserved
https://www.direct-netware.de/redirect?dpt;module_loader

This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can
obtain one at http://mozilla.org/MPL/2.0/.
----------------------------------------------------------------------------
https://www.direct-netware.de/redirect?licenses;mpl2
----------------------------------------------------------------------------
v1.0.5
dpt_module_loader/class_loader.py
"""

from dpt_runtime.exceptions import IOException, TypeException

from .loader import Loader

class ClassLoader(Loader):
    """
"ClassLoader" provides singletons and objects based on the package, module
and class name given as "package.module:Class".

:author:     direct Netware Group et al.
:copyright:  direct Netware Group - All rights reserved
:package:    dpt
:subpackage: module_loader
:since:      v1.0.0
:license:    https://www.direct-netware.de/redirect?licenses;mpl2
             Mozilla Public License, v. 2.0
    """

    __slots__ = ( "__weakref__", "config" )
    """
python.org: __slots__ reserves space for the declared variables and prevents
the automatic creation of __dict__ and __weakref__ for each instance.
    """
    _instance = None
    """
"Loader" weakref instance
    """

    def __init__(self):
        """
Constructor __init__(ClassLoader)

:since: v1.0.0
        """

        self.config = { }
        """
Underlying configuration array
        """
    #

    def get(self, _class):
        """
Returns the registered class name if applicable.

:param _class: Package, module and class name

:return: (str) Registered class name
:since:  v1.0.0
        """

        return self.config.get(_class)
    #

    def is_registered(self, _class):
        """
Checks if a given class is known.

:param _class: Package, module and class name

:return: (bool) True if defined
:since:  v1.0.0
        """

        return (_class in self.config)
    #

    def register(self, _class, registered_class):
        """
Registers an alternative class for the specified package, module and class
name.

:param _class: Package, module and class name
:param registered_class: Alternative class

:since: v1.0.0
        """

        self.config[_class] = registered_class
    #

    def unregister(self, _class):
        """
Unregisters an alternative class for the specified package, module and class
name.

:param _class: Package, module and class name

:since: v1.0.0
        """

        if (_class in self.config):
            with ClassLoader._lock:
                # Thread safety
                if (_class in self.config): del(self.config[_class])
            #
        #
    #

    @staticmethod
    def get_class(_class, autoload = True):
        """
Get the class for the specified package, module and class name.

:param _class: Package, module and class name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (object) Loaded class; None on error
:since:  v1.0.0
        """

        loader = ClassLoader.get_class_loader_instance()
        if (loader.is_registered(_class)): _class = loader.get(_class)

        class_data = _class.rsplit(":", 1)
        if (len(class_data) < 2): raise IOException("Class '{0}' given is invalid".format(_class))

        class_name = class_data[1]
        module = Loader.get_module(class_data[0], autoload)

        return (None if (module is None) else getattr(module, class_name, None))
    #

    @staticmethod
    def get_class_in_namespace(namespace_package, _class, autoload = True):
        """
Get the class located in the specified namespace, package and module name.

:param namespace_package: Namespace package name
:param _class: Package, module and class name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (object) Loaded class; None on error
:since:  v1.0.0
        """

        class_data = _class.rsplit(":", 1)
        if (len(class_data) < 2): raise IOException("Class '{0}' given is invalid".format(_class))

        class_name = class_data[1]
        module = Loader.get_module_in_namespace(namespace_package, class_data[0], autoload)

        return (None if (module is None) else getattr(module, class_name, None))
    #

    @classmethod
    def get_class_loader_instance(cls):
        """
Get the loader instance.

:param cls: Python class

:return: (object) Loader instance
:since:  v1.0.0
        """

        if (ClassLoader._instance is None):
            with ClassLoader._lock:
                # Thread safety
                if (ClassLoader._instance is None): ClassLoader._instance = ClassLoader()
            #
        #

        return ClassLoader._instance
    #

    @staticmethod
    def get_instance(_class, required = True, **kwargs):
        """
Returns a new instance based on the specified package, module and class
name.

:param _class: Package, module and class name
:param required: True if exceptions should be thrown if the class is not
                 defined.

:return: (object) Requested object on success
:since:  v1.0.0
        """

        _return = None

        instance_class = ClassLoader.get_class(_class)

        if (instance_class is not None and issubclass(instance_class, object)): _return = instance_class(**kwargs)
        if (_return is None and required): raise IOException("Class '{0}' is not defined".format(_class))

        return _return
    #

    @staticmethod
    def get_instance_in_namespace(namespace_package, _class, required = True, **kwargs):
        """
Returns a new instance based on the specified namespace, package and module
name.

:param namespace_package: Namespace package name
:param _class: Package, module and class name
:param required: True if exceptions should be thrown if the class is not
                 defined.

:return: (object) Requested object on success
:since:  v1.0.0
        """

        _return = None

        instance_class = ClassLoader.get_class_in_namespace(namespace_package, _class)

        if (instance_class is not None and issubclass(instance_class, object)): _return = instance_class(**kwargs)
        if (_return is None and required): raise IOException("Class '{0}' is not defined".format(_class))

        return _return
    #

    @staticmethod
    def get_singleton(_class, required = True, **kwargs):
        """
Returns a singleton based on the specified package, module and class name.

:param _class: Package, module and class name
:param required: True if exceptions should be thrown if the class is not
                 defined.

:return: (object) Requested object on success
:since:  v1.0.0
        """

        _return = None

        singleton_class = ClassLoader.get_class(_class)

        if (singleton_class is None and required): raise IOException("Class '{0}' is not defined".format(_class))

        if (hasattr(singleton_class, "get_instance")
            and callable(singleton_class.get_instance)
           ): _return = singleton_class.get_instance(**kwargs)
        elif (required): raise TypeException("{0} has not defined a singleton".format(_class))

        return _return
    #

    @staticmethod
    def is_defined(_class, autoload = True):
        """
Checks if the specified package, module and class name is defined or can be
resolved after auto loading it.

:param _class: Package, module and class name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (bool) True if defined or resolvable
:since:  v1.0.0
        """

        return (ClassLoader.get_class(_class, autoload) is not None)
    #

    @staticmethod
    def is_defined_in_namespace(namespace_package, _class, autoload = True):
        """
Checks if the specified class located in the specified namespace, package
and module name is defined or can be resolved after auto loading it.

:param namespace_package: Namespace package name
:param _class: Package, module and class name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (bool) True if defined or resolvable
:since:  v1.0.0
        """

        return (ClassLoader.get_class_in_namespace(namespace_package, _class, autoload) is not None)
    #

    @staticmethod
    def reload(_class, clear_caches = True):
        """
Reloads the the specified package module.

:param _class: Package, module and optional class name
:param clear_caches: True to clear import caches before reloading

:return: (object) Reloaded module on success
:since:  v1.0.0
        """

        loader = ClassLoader.get_class_loader_instance()
        if (loader.is_registered(_class)): _class = loader.get(_class)

        class_data = _class.rsplit(":", 1)
        return Loader.reload((_class if (len(class_data) < 2) else class_data[0]), clear_caches)
    #
#



# -*- coding: utf-8 -*-

"""
direct Python Toolbox
All-in-one toolbox to encapsulate Python runtime variants
----------------------------------------------------------------------------
(C) direct Netware Group - All rights reserved
https://www.direct-netware.de/redirect?dpt;module_loader

This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can
obtain one at http://mozilla.org/MPL/2.0/.
----------------------------------------------------------------------------
https://www.direct-netware.de/redirect?licenses;mpl2
----------------------------------------------------------------------------
v1.0.5
dpt_module_loader/loader.py
"""

# pylint: disable=import-error,invalid-name

from contextlib import contextmanager
from os import path
from weakref import proxy
import os
import sys

from dpt_runtime.exceptions import IOException
from dpt_threading import ThreadLock

_MODE_IMP = 1
"""
Use "imp" based methods for import
"""
_MODE_IMPORTLIB = 2
"""
Use "importlib" based methods for import
"""

_mode = _MODE_IMPORTLIB

try: import importlib
except ImportError:
    import imp
    _mode = _MODE_IMP
#

class Loader(object):
    """
"Loader" provides singletons and objects based on the package, module
and class name given as "package.module:Class".

:author:     direct Netware Group et al.
:copyright:  direct Netware Group - All rights reserved
:package:    dpt
:subpackage: module_loader
:since:      v1.0.0
:license:    https://www.direct-netware.de/redirect?licenses;mpl2
             Mozilla Public License, v. 2.0
    """

    __slots__ = ( )
    """
python.org: __slots__ reserves space for the declared variables and prevents
the automatic creation of __dict__ and __weakref__ for each instance.
    """
    _additional_base_dir = None
    """
Additional base directory we search for python files
    """
    _lock = ThreadLock()
    """
Thread safety lock
    """
    _log_handler = None
    """
The log handler is called whenever debug messages should be logged or errors
happened.
    """
    _namespace_modules_cache = { }
    """
Cache of loaded modules using "get_module_in_namespace()".
    """

    @staticmethod
    def get_base_dirs():
        """
Returns the base directories for scanning and loading python files.

:return: (str) Base paths
:since:  v1.0.0
        """

        if (Loader._additional_base_dir is not None): yield Loader._additional_base_dir

        for _path in sys.path:
            if (_path == ""): _path = "."
            if (not path.isdir(_path)): continue

            yield _path
        #
    #

    @staticmethod
    def get_module(package_module, autoload = True):
        """
Get the module for the specified package and module name.

:param package_module: Package and module name
:param autoload: True to load the module automatically if not done already.

:return: (object) Python module; None on error
:since:  v1.0.0
        """

        package_module_data = package_module.rsplit(".", 1)

        package = (None if (len(package_module_data) < 2) else package_module_data[0])
        module = package_module_data[-1]

        _callable = (Loader._load_module if (autoload) else Loader._get_module)
        return _callable(package, module)
    #

    @staticmethod
    def get_module_in_namespace(namespace_package, package_module, autoload = True):
        """
Get the module located in the specified namespace, package and module name.

:param namespace_package: Namespace package name
:param package_module: Package and module name
:param autoload: True to load the module automatically if not done already.

:return: (object) Python module; None on error
:since:  v1.0.0
        """

        _return = None

        package_module_name = "{0}.{1}".format(namespace_package, package_module)
        cached_package_module_name = Loader._namespace_modules_cache.get(package_module_name)

        if (cached_package_module_name is not None):
            _return = Loader._get_module(cached_package_module_name)

            if (_return is None):
                with Loader._lock:
                    # Thread safety
                    if (package_module_name in Loader._namespace_modules_cache):
                        del(Loader._namespace_modules_cache[package_module_name])
                    #
                #
            #
        #

        if (_return is None):
            _callable = (Loader._load_module_without_exception_logging if (autoload) else Loader._get_module)
            package_module_data = package_module.rsplit(".", 1)

            sub_package = (namespace_package
                           if (len(package_module_data) < 2) else
                           "{0}.{1}".format(namespace_package, package_module_data[0])
                          )

            module = package_module_data[-1]

            for _path in Loader.get_base_dirs():
                for dir_entry in os.listdir(_path):
                    namespace_package_path = path.join(_path, dir_entry, namespace_package.replace(".", path.sep))
                    package = "{0}.{1}".format(dir_entry, sub_package)

                    if (path.isdir(namespace_package_path)):
                        _return = _callable(package, module)

                        if (_return is not None):
                            Loader._namespace_modules_cache[package_module_name] = "{0}.{1}".format(package, module)
                            break
                        #
                    #
                #
            #
        #

        return _return
    #

    @staticmethod
    def _get_module(package, module = None):
        """
Returns the initialized Python module if applicable.

:param package: Package name
:param module: Module name

:return: (object) Python module; None if unknown
:since:  v1.0.0
        """

        package_module_name = None

        if (package is not None and module is not None): package_module_name = "{0}.{1}".format(package, module)
        elif (module is None): package_module_name = package
        else: package_module_name = module

        return (None if (package_module_name is None) else sys.modules.get(package_module_name))
    #

    @staticmethod
    def _import(package, module = None, log_exceptions = True):
        """
Imports the Python module.

:param package: Package name
:param module: Module name
:param log_exceptions: True to log exceptions thrown

:return: (object) Python module; None if unknown
:since:  v1.0.0
        """

        # global: _mode, _MODE_IMPORTLIB
        # pylint: disable=broad-except

        _return = Loader._get_module(package, module)

        if (_return is None):
            with Loader._lock:
                # Thread safety
                _return = Loader._get_module(package, module)
                _callable = (Loader._import_with_importlib if (_mode == _MODE_IMPORTLIB) else Loader._import_with_imp)

                if (_return is None):
                    try: _return = _callable(package, module)
                    except Exception as handled_exception:
                        if (log_exceptions and Loader._log_handler is not None): Loader._log_handler.error(handled_exception, context = "dpt_module_loader")
                    #
                #
            #
        #

        return _return
    #

    @staticmethod
    def _import_with_imp(package, module):
        """
Imports the Python module with "imp".

:param package: Package name
:param module: Module name

:return: (object) Python module; None if unknown
:since:  v1.0.0
        """

        _return = None

        base_path = None
        base_path_entry = ""
        package_directory = None
        package_module_name = module

        if (package is None):
            base_path_entry = "{0}.py".format(module)
        else:
            base_path_entry = package.split(".", 1)[0]
            package_directory = package.replace(".", path.sep)
            package_module_name = "{0}.{1}".format(package, module)
        #

        if (base_path_entry == ""): raise IOException("Import base path '{0}' is empty".format(base_path_entry))

        for _path in Loader.get_base_dirs():
            if (os.access(path.join(_path, base_path_entry), os.R_OK)):
                base_path = _path
                break
            #
        #

        if (base_path is not None and package_directory is not None):
            base_path = path.join(base_path, package_directory)
        #

        if (base_path is not None):
            with _imp_lock():
                ( file_obj, file_path, description ) = imp.find_module(module, [ base_path ])
                _return = imp.load_module(package_module_name, file_obj, file_path, description)
                if (file_obj is not None): file_obj.close()
            #
        #

        return _return
    #

    @staticmethod
    def _import_with_importlib(package, module):
        """
Imports the Python module with "importlib".

:param package: Package name
:param module: Module name

:return: (object) Python module; None if unknown
:since:  v1.0.0
        """

        _return = None

        package_module_name = None

        if (package is not None and module is not None): package_module_name = "{0}.{1}".format(package, module)
        elif (module is None): package_module_name = package
        else: package_module_name = module

        if (package_module_name is not None): _return = importlib.import_module(package_module_name)
        return _return
    #

    @staticmethod
    def is_defined(package_module, autoload = True):
        """
Checks if the specified package, module and class name is defined or can be
resolved after auto loading it.

:param package_module: Package and module name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (bool) True if defined or resolvable
:since:  v1.0.0
        """

        return (Loader.get_module(package_module, autoload) is not None)
    #

    @staticmethod
    def _load_module(package, module, log_exceptions = True):
        """
Loads the Python package and module.

:param package: Package name
:param module: Module name
:param log_exceptions: True to log exceptions thrown

:return: (object) Python module; None if unknown
:since:  v1.0.0
        """

        if (package is not None): Loader._import(package, log_exceptions = log_exceptions)
        return Loader._import(package, module, log_exceptions)
    #

    @staticmethod
    def _load_module_without_exception_logging(package, module):
        """
Loads the Python package and module without logging any traces of
exceptions.

:param package: Package name
:param module: Module name

:return: (object) Python module; None if unknown
:since:  v1.0.0
        """

        return Loader._load_module(package, module, False)
    #

    @staticmethod
    def reload(package_module, clear_caches = True):
        """
Reloads the the specified package module.

:param package_module: Package and module name
:param clear_caches: True to clear import caches before reloading

:return: (object) Reloaded module on success
:since:  v1.0.0
        """

        # global: _mode, _MODE_IMPORTLIB
        # pylint: disable=no-member

        _return = None

        module = Loader._get_module(package_module)

        if (module is not None):
            try:
                if (_mode == _MODE_IMPORTLIB):
                    if (clear_caches and hasattr(importlib, "invalidate_caches")): importlib.invalidate_caches()
                    _return = importlib.reload(module)
                else: _return = imp.reload(module)
            except ImportError as handled_exception:
                if (Loader._log_handler is not None): Loader._log_handler.debug(handled_exception, context = "dpt_module_loader")
            #
        #

        return _return
    #

    @staticmethod
    def set_additional_base_dir(base_dir):
        """
Sets an additional base directory for scanning and loading python files.

:param base_dir: Path

:since: v1.0.0
        """

        Loader._additional_base_dir = path.abspath(base_dir)
    #

    @staticmethod
    def set_log_handler(log_handler):
        """
Sets the log handler.

:param log_handler: Log handler to use

:since: v1.0.0
        """

        Loader._log_handler = proxy(log_handler)
    #
#

@contextmanager
def _imp_lock():
    """
Helper method to lock and unlock the importer safely.

:since: v1.0.0
    """

    imp.acquire_lock()
    yield
    imp.release_lock()
#



# -*- coding: utf-8 -*-

"""
direct Python Toolbox
All-in-one toolbox to encapsulate Python runtime variants
----------------------------------------------------------------------------
(C) direct Netware Group - All rights reserved
https://www.direct-netware.de/redirect?dpt;module_loader

This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can
obtain one at http://mozilla.org/MPL/2.0/.
----------------------------------------------------------------------------
https://www.direct-netware.de/redirect?licenses;mpl2
----------------------------------------------------------------------------
v1.0.5
dpt_module_loader/named_class_loader.py
"""

import re

from .class_loader import ClassLoader

class NamedClassLoader(ClassLoader):
    """
"NamedClassLoader" provides singletons and objects based on a callable
common name.

:author:     direct Netware Group et al.
:copyright:  direct Netware Group - All rights reserved
:package:    dpt
:subpackage: module_loader
:since:      v1.0.0
:license:    https://www.direct-netware.de/redirect?licenses;mpl2
             Mozilla Public License, v. 2.0
    """

    RE_CAMEL_CASE_SPLITTER = re.compile("([A-Z]+|[a-z0-9])([A-Z])(?!$)")
    """
CamelCase splitter RegExp
    """
    RE_NON_WORD_CAMEL_CASE_SPLITTER = re.compile("[^a-zA-Z0-9]+")
    """
CamelCase generation RegExp
    """

    __slots__ = ( )
    """
python.org: __slots__ reserves space for the declared variables and prevents
the automatic creation of __dict__ and __weakref__ for each instance.
    """

    @staticmethod
    def get_camel_case_class_name(name):
        """
Returns the class name in camel case for the given name.

:param name: Class name like "example_class_name"

:return: (str) Class name in camel case
:since:  v1.0.0
        """

        return "".join([ word.capitalize() for word in NamedClassLoader.RE_NON_WORD_CAMEL_CASE_SPLITTER.split(name) ])
    #

    @staticmethod
    def get_class(common_name, autoload = True):
        """
Get the class name for the given common name.

:param common_name: Common name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (object) Loaded class; None on error
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.get_class(_class, autoload)
    #

    @staticmethod
    def get_class_from_common_name(common_name):
        """
Returns the package, module and class name for the common one.

:param common_name: Common name like "dpt_module_loader.ClassLoader"

:return: (str) Package, module and class name
:since:  v1.0.0
        """

        _return = None

        common_name_data = common_name.rsplit(".", 1)
        module_name = NamedClassLoader.RE_CAMEL_CASE_SPLITTER.sub("\\1_\\2", common_name_data[-1]).lower()

        return ("{0}:{1}".format(module_name, common_name_data[0])
                if (len(common_name_data) < 2) else
                "{0}.{1}:{2}".format(common_name_data[0], module_name, common_name_data[1])
               )
    #

    @staticmethod
    def get_class_in_namespace(namespace_package, common_name, autoload = True):
        """
Get the class name for the given namespace package and common name.

:param namespace_package: Namespace package name
:param common_name: Common name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (object) Loaded class; None on error
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.get_class_in_namespace(namespace_package, _class, autoload)
    #

    @staticmethod
    def get_instance(common_name, required = True, **kwargs):
        """
Returns a new instance based on its common name.

:param common_name: Common name
:param required: True if exceptions should be thrown if the class is not
                 defined.
:param autoload: True to load the class automatically if not done already

:return: (object) Requested object on success
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.get_instance(_class, required, **kwargs)
    #

    @staticmethod
    def get_instance_in_namespace(namespace_package, common_name, required = True, **kwargs):
        """
Returns a new instance based on the specified namespace package and common
name.

:param namespace_package: Namespace package name
:param common_name: Common name
:param required: True if exceptions should be thrown if the class is not
                 defined.

:return: (object) Requested object on success
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.get_instance_in_namespace(namespace_package, _class, required, **kwargs)
    #

    @staticmethod
    def get_singleton(common_name, required = True, **kwargs):
        """
Returns a singleton based on its common name.

:param common_name: Common name
:param required: True if exceptions should be thrown if the class is not
                 defined.

:return: (object) Requested object on success
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.get_singleton(_class, required, **kwargs)
    #

    @staticmethod
    def is_defined(common_name, autoload = True):
        """
Checks if a common name is defined or can be resolved to a class name.

:param common_name: Common name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (bool) True if defined or resolvable
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.is_defined(_class, autoload)
    #

    @staticmethod
    def is_defined_in_namespace(namespace_package, common_name, autoload = True):
        """
Checks if the specified class located in the specified namespace, package
and module name is defined or can be resolved after auto loading it.

:param namespace_package: Namespace package name
:param common_name: Common name
:param autoload: True to load the class module automatically if not done
                 already.

:return: (bool) True if defined or resolvable
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.is_defined_in_namespace(namespace_package, _class, autoload)
    #

    @staticmethod
    def reload(common_name, clear_caches = True):
        """
Reloads the the specified package module.

:param common_name: Common name
:param clear_caches: True to clear import caches before reloading

:return: (object) Reloaded module on success
:since:  v1.0.0
        """

        _class = NamedClassLoader.get_class_from_common_name(common_name)
        return ClassLoader.reload(_class, clear_caches)
    #
#



# -*- coding: utf-8 -*-

"""
direct Python Toolbox
All-in-one toolbox to encapsulate Python runtime variants
----------------------------------------------------------------------------
(C) direct Netware Group - All rights reserved
https://www.direct-netware.de/redirect?dpt;module_loader

This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can
obtain one at http://mozilla.org/MPL/2.0/.
----------------------------------------------------------------------------
https://www.direct-netware.de/redirect?licenses;mpl2
----------------------------------------------------------------------------
setup.py
"""

from os import makedirs, path

try:
    from setuptools import find_packages, setup
except ImportError:
    from distutils import find_packages, setup
#

_use_dist_mode = False

try:
    from dpt_builder_suite.distutils.build_py import BuildPy
    from dpt_builder_suite.distutils.sdist import Sdist
    from dpt_builder_suite.distutils.temporary_directory import TemporaryDirectory
except ImportError:
    _use_dist_mode = True
#

def get_version():
    """
Returns the version currently in development.

:return: (str) Version string
:since:  v1.0.0
    """

    return "v1.0.5"
#

with open("requirements.txt", "r") as fp:
    requirements_list = [ line.strip() for line in fp.readlines() if line.strip() != "" ]
#

_setup = { "version": get_version()[1:],
           "install_requires": requirements_list,
           "data_files": [ ( "docs", [ "LICENSE", "README" ]) ],
           "test_suite": "tests"
         }

if (_use_dist_mode):
    _setup['package_dir'] = { "": "src" }
    _setup['packages'] = find_packages("src")

    setup(**_setup)
else:
    with TemporaryDirectory(dir = ".") as build_directory:
        parameters = { "dptModuleLoaderVersion": get_version() }

        BuildPy.set_build_target_path(build_directory)
        BuildPy.set_build_target_parameters(parameters)

        Sdist.set_build_target_path(build_directory)
        Sdist.set_build_target_parameters(parameters)

        package_dir = path.join(build_directory, "src")
        makedirs(package_dir)

        _setup['package_dir'] = { "": package_dir }
        _setup['packages'] = [ "dpt_module_loader" ]

        # Customize "cmdclass" to first run builder.py
        _setup['cmdclass'] = { "build_py": BuildPy, "sdist": Sdist }

        setup(**_setup)
    #
#



# -*- coding: utf-8 -*-

"""
direct Python Toolbox
All-in-one toolbox to encapsulate Python runtime variants
----------------------------------------------------------------------------
(C) direct Netware Group - All rights reserved
https://www.direct-netware.de/redirect?dpt;module_loader

This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can
obtain one at http://mozilla.org/MPL/2.0/.
----------------------------------------------------------------------------
https://www.direct-netware.de/redirect?licenses;mpl2
----------------------------------------------------------------------------
v1.0.5
dpt_module_loader/__init__.py
"""

from .class_loader import ClassLoader
from .named_class_loader import NamedClassLoader
from .loader import Loader
